@@ -1,25 +1,25 @@
 package Map::Tube::Delhi::Line::Green;
 
-$Map::Tube::Delhi::Line::Green::VERSION = '0.18';
+$Map::Tube::Delhi::Line::Green::VERSION = '0.19';
 
 =head1 NAME
 
-Map::Tube::Delhi::Line::Green - List stations for Delhi Metro Green Line.
+Map::Tube::Delhi::Line::Green - Delhi Metro Green Line stations.
 
 =head1 VERSION
 
-Version 0.18
+Version 0.19
 
 =head1 DESCRIPTION
 
-Station belonging to the Green Line of Delhi Metro as listed below
+Delhi Metro Green Line stations.
 
     +-------------------------+------------------------------------------------+
-    | Name                    | Linked To                                      |
+    | Station Name            | Linked To                                      |
     +-------------------------+------------------------------------------------+
     | Mundka                  | Rajdhani Park                                  |
-    | Rajdhani Park           | Nagloi Railway Station, Mundka                 |
-    | Nangloi Railway Station | Nagloi, Rajdhani Park                          |
+    | Rajdhani Park           | Nangloi Railway Station, Mundka                |
+    | Nangloi Railway Station | Nangloi, Rajdhani Park                         |
     | Nangloi                 | Surajmal Stadium, Nangloi Railway Station      |
     | Surajmal Stadium        | Udyog Nagar, Nangloi                           |
     | Udyog Nagar             | Peeragarhi, Surajmal Stadium                   |
@@ -29,11 +29,11 @@ Station belonging to the Green Line of Delhi Metro as listed below
     | Madipur                 | Shivaji Park, Paschim Vihar East               |
     | Shivaji Park            | Punjabi Bagh, Madipur                          |
     | Punjabi Bagh            | Ashok Park Main, Shivaji Park                  |
-    | Ashok Park Main         | Inderlok, Punjabi Bagh, Staguru Ram Singh Marg |
+    | Ashok Park Main         | Inderlok, Punjabi Bagh, Satguru Ram Singh Marg |
     | Inderlok                | Ashok Park Main                                |
     | Satguru Ram Singh Marg  | Kirti Nagar, Ashok Park Main                   |
     | Kirti Nagar             | Satguru Ram Singh Marg                         |
-    +----------------------+---------------------------------------------------+
+    +-------------------------+------------------------------------------------+
 
 =head1 AUTHOR
 
